.. _swh-shard:

.. include:: README.rst

Low level management for read-only content-addressable object storage
indexed with a perfect hash table.


Reference Documentation
-----------------------

.. toctree::
   :maxdepth: 2

   format
   benchmarks

.. only:: standalone_package_doc

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
